@@ -85,7 +85,7 @@ def giska(fasta_path):
         logger.info("Finished writing to suffix_array.txt")
 
     except Exception as exc:
-        logger.error(f'Following exception occurred {exc}')
+        logger.error(f'Following exception occurred', exc)
 
 
 @cli.command()
@@ -122,7 +122,7 @@ def ekstendovic(fasta_path, fastq_path, occurrences_matrix_path, c_path,
         logger.info('Finished writing results to csv file')
 
     except Exception as exc:
-        logger.error(f'Following exception occurred {exc}')
+        logger.error(f'Following exception occurred', exc)
 
 
 if __name__ == '__main__':
