@@ -13,27 +13,29 @@ def get_seed(seed_length, read):
 
 # make coarse then do fine refine
 def seed_and_extend(reference, reads, occ_matrix, c, suff_arr, scoring_points, margin=3, seed_length=10):
-
     result = []
     for read in reads:
-        # for each read extract substrins - seeds and reverse complement
+        # for each read extract substrings - seeds and reverse complement
         rc_read = reverse_and_complement(read)
 
         seed = get_seed(seed_length, read)
         rc_seed = get_seed(seed_length, rc_read)
 
-        result.extend(extract(c, margin, occ_matrix, read, reference, seed, seed_length, scoring_points, suff_arr))
-        result.extend(extract(c, margin, occ_matrix, rc_read, reference, rc_seed, seed_length, scoring_points, suff_arr))
+        # Added direction to be able to have more info in the result
+        result.extend(
+            extract(c, margin, occ_matrix, read, reference, seed, seed_length, scoring_points, suff_arr, dir="fwd"))
+        result.extend(
+            extract(c, margin, occ_matrix, rc_read, reference, rc_seed, seed_length, scoring_points, suff_arr, dir="rc"))
 
-    return sorted(result, key=lambda tup: tup[2], reverse=True)
+    return sorted(result, key=lambda tup: tup[3], reverse=True)
 
 
-def extract(c, margin, occ_matrix, read, reference, seed, seed_length, scoring_points, suff_arr):
+def extract(c, margin, occ_matrix, read, reference, seed, seed_length, scoring_points, suff_arr, dir):
     start, end = calculate_start_end_range(c, occ_matrix, seed)
     if (start, end) == (-1, -1):
         return []
     seed_positions = find_all_query_positions_in_word_via_suffix_arr(start, end, suff_arr)
-    # ref     "ctagtcgt agctagctgatcg"
+    # ref     "ctgctgt agctagctgatcg"
     # read    "gctgt cgtc"
     # s       "gctgt"
     result = []
@@ -47,6 +49,6 @@ def extract(c, margin, occ_matrix, read, reference, seed, seed_length, scoring_p
                                                       scoring_points)
         alignment, transcript = traceback(read[seed_length:], reference[start_pos:end_pos], distances,
                                           scoring_points)
-        result.append((start, end, alignment_score, transcript))
+        result.append((start, end, dir, alignment_score, transcript))
 
     return result
